#' Sample annotation data version 1
#'
#' This is data from BXD aging study with mock instruments to show how
#' instrument-specific functionality works
#'
#' @format A data frame with 233 rows and 11 variables:
#' \describe{
#'   \item{FullRunName}{name of the file, in most functions used for \code{sample_id_col}}
#'   \item{MS_batch}{mass-spectrometry batch: 7-level factor of 
#'   manually annotated batches}
#'   \item{EarTag}{mouse ID, i.e. ID of the biological object}
#'   \item{Strain}{mouse strain ID - biological covariate #1}
#'   \item{Diet}{diet - either \code{HFD} = `High Fat Diet` or \code{CD} = `Chow Diet`.
#'   \code{Mix} stands for mixture of several samples}
#'   \item{Sex}{mice sex - 3-level biological covariate. Possible values - ''}
#'   \item{RunDate}{mass-spectrometry running date. In combination 
#'   with \code{RunTime} used for running order determination}
#'   \item{RunTime}{mass-spectrometry running time. In combination 
#'   with \code{RunDate} used for running order determination}
#'   \item{DateTime}{numeric date and time generated by \code{date_to_sample_order}}
#'   \item{order}{order of samples generated by sorting DateTime 
#'   in \code{date_to_sample_order}}
#'   \item{digestion_batch}{peptide digestion batch: 5-level 
#'   factor of manually annotated batches}
#'   ...
#' }
"example_sample_annotation"

#' Example protein data in long format  
#'
#' This is data from Aging study with all iRT, spike-in peptides,
#' few random peptides and QTL proteins for biological 
#' signal improvement demonstration
#'
#' @format A data frame with 124655 rows and 5 variables:
#' \describe{
#'   \item{peptide_group_label}{peptide ID, which is regular feature level. 
#'   This column is mostly used as \code{feature_id_col}}
#'   \item{Intensity}{peptide group intensity in given sample. 
#'   Used in function as \code{measure_col}}
#'   \item{ProteinName}{Protein group ID, specified as 
#'   N/UniProtID1|UniProtID2|...,
#'   where N is number of protein peptide group maps to. If 
#'   1/UniProtID, then this is proteotypic peptide}
#'   \item{Gene}{conventional gene name of corresponding ProteinName}
#'   \item{FullRunName}{name of the file, in most functions used for \code{sample_id_col}}
#' ...
#' }
#' @source PRIDE ID will be added in future
"example_proteome"

#' Example protein data in matrix 
#'
#' This is measurement data from Aging study with columns
#' representing samples and rows representing peptides
#'
#' @format A matrix with 534 rows and 233 columns:
#' 
#' @source PRIDE ID will be added in future
"example_proteome_matrix"

#' Peptide annotation data
#'
#' This is data from Aging study annotated with gene names
#'
#' @format A data frame with 535 rows and 10 variables:
#' \describe{
#'   \item{peptide_group_label}{peptide group label ID, identical to 
#'   \code{peptide_group_label} in \code{example_proteome}}
#'   \item{Gene}{HUGO gene ID}
#'   \item{ProteinName}{protein group name as specified in \code{example_proteome}}
#'   }
"example_peptide_annotation"


#' Sample color annotation 
#'
#' This is an color scheme generated from example sample annotation 
#'
#' @format A list of 3 components: \code{list_of_colors}, \code{color_df} and 
#' \code{sample_annotation}
#' \describe{
#'   \item{list_of_colors}{a list of colors for 11 variables, including \code{MS_batch},
#'   \code{EarTag}, \code{Strain}, \code{Diet}, \code{digestion_batch}, \code{Sex}, \code{FullRunName},
#'   \code{RunDate}, \code{RunTime}, \code{DateTime}, \code{order}}
#'   \item{color_df}{a data frame with 233 samples and 11 variables describing a color for each component}
#'   \item{sample_anotation}{a data frame containing 233 samples and 11 variables annotating samples 
#'   to facilitate conversion to a color scheme}
#'   }
"sample_color_scheme"
