% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/feature_level_diagnostics.R
\name{plot_single_feature}
\alias{plot_single_feature}
\title{Plot peptide measurements}
\usage{
plot_single_feature(pep_name, df_long, sample_annotation,
  order_col = "order", sample_id_col = "FullRunName",
  batch_col = "MS_batch", measure_col = "Intensity",
  feature_id_col = "peptide_group_label", geom = c("point", "line"),
  color_by_batch = FALSE, color_scheme = "brewer",
  facet_by_batch = FALSE, color_by_col = NULL, color_by_value = NULL,
  plot_title = NULL, vline_color = "red", theme = "classic")
}
\arguments{
\item{pep_name}{name of the peptide for diagnostic profiling}

\item{df_long}{data frame where each row is a single feature in a single
sample. It minimally has a \code{sample_id_col}, a \code{feature_id_col} and a
\code{measure_col}, but usually also an \code{m_score} (in OpenSWATH output result
file)}

\item{sample_annotation}{data matrix with: \enumerate{ \item \code{sample_id_col}
(this can be repeated as row names) \item biological covariates \item
technical covariates (batches etc) }}

\item{order_col}{column in \code{sample_annotation} that determines sample order. It is
used for certain diagnostics and normalisations.}

\item{sample_id_col}{name of the column in sample_annotation file, where the
filenames (colnames of the data matrix are found)}

\item{batch_col}{column in \code{sample_annotation} that should be used for
batch comparison}

\item{measure_col}{if \code{df_long} is among the parameters, it is the
column with expression/abundance/intensity; otherwise, it is used
internally for consistency}

\item{feature_id_col}{name of the column with feature/gene/peptide/protein
ID used in the long format representation \code{df_long}. In the wide
formatted representation \code{data_matrix} this corresponds to the row
names.}

\item{geom}{whether to show the feature as points and/or connect by lines}

\item{color_by_batch}{(logical) whether to color points by batch}

\item{color_scheme}{color scheme for \code{ggplot} representation}

\item{facet_by_batch}{(logical) whether to plot each batch in its own facet}

\item{color_by_col}{column to color by certain value denoted 
by \code{color_by_value}}

\item{color_by_value}{value in \code{color_by_col} to color}

\item{plot_title}{the string indicating the source of the peptides}

\item{vline_color}{color of vertical lines, typically denoting 
different MS batches in ordered runs; should be \code{NULL} for 
experiments without intrinsic order}

\item{theme}{plot theme (default is 'classical'; other options not
implemented)}
}
\value{
ggplot2 type plot of \code{measure_col} vs \code{order_col},
  faceted by \code{pep_name} and (optionally) by \code{batch_col}
}
\description{
Creates a peptide facetted ggplot2 plot of the value in \code{measure_col}
vs \code{order_col}. Additionally, the resulting plot can also be facetted
by batch.
}
\examples{
single_feature_plot <- plot_single_feature(
pep_name = "46213_NVGVSFYADKPEVTQEQK_2", 
df_long = example_proteome, example_sample_annotation, 
color_by_col = NULL)

}
\seealso{
Other feature-level diagnostic functions: \code{\link{plot_iRT}},
  \code{\link{plot_peptides_of_one_protein}},
  \code{\link{plot_spike_in}},
  \code{\link{plot_with_fitting_curve}}
}
\concept{feature-level diagnostic functions}
